searchData={"items":[{"type":"module","title":"UXID","doc":"Generates UXIDs and acts as an Ecto ParameterizedType\n\n**U**ser e**X**perience focused **ID**entifiers (UXIDs) are identifiers which:\n\n* Describe the resource (aid in debugging and investigation)\n* Work well with copy and paste (double clicking selects the entire ID)\n* Can be shortened for low cardinality resources\n* Are secure against enumeration attacks\n* Can be generated by application code (not tied to the datastore)\n* Are K-sortable (lexicographically sortable by time - works well with datastore indexing)\n* Do not require any coordination (human or automated) at startup, or generation\n* Are very unlikely to collide (more likely with less randomness)\n* Are easily and accurately transmitted to another human using a telephone\n\nMany of the concepts of Stripe IDs have been used in this library.","ref":"UXID.html"},{"type":"function","title":"UXID.autogenerate/1","doc":"Generates a loaded version of the UXID.","ref":"UXID.html#autogenerate/1"},{"type":"function","title":"UXID.cast/2","doc":"Casts the given input to the UXID ParameterizedType with the given parameters.","ref":"UXID.html#cast/2"},{"type":"function","title":"UXID.dump/3","doc":"Dumps the given term into an Ecto native type.","ref":"UXID.html#dump/3"},{"type":"function","title":"UXID.encode_case/0","doc":"","ref":"UXID.html#encode_case/0"},{"type":"type","title":"UXID.error_string/0","doc":"An error string returned by the library if generation fails","ref":"UXID.html#t:error_string/0"},{"type":"function","title":"UXID.generate/1","doc":"Returns an encoded UXID string along with response status.","ref":"UXID.html#generate/1"},{"type":"function","title":"UXID.generate!/1","doc":"Returns an unwrapped encoded UXID string or raises on error.","ref":"UXID.html#generate!/1"},{"type":"function","title":"UXID.init/1","doc":"Converts the options specified in the field macro into parameters to be used in other callbacks.","ref":"UXID.html#init/1"},{"type":"function","title":"UXID.load/3","doc":"Loads the given term into a UXID.","ref":"UXID.html#load/3"},{"type":"function","title":"UXID.new/1","doc":"Returns a new UXID struct. This is useful for development.","ref":"UXID.html#new/1"},{"type":"type","title":"UXID.option/0","doc":"Options for generating a UXID","ref":"UXID.html#t:option/0"},{"type":"type","title":"UXID.options/0","doc":"","ref":"UXID.html#t:options/0"},{"type":"type","title":"UXID.t/0","doc":"A UXID struct","ref":"UXID.html#t:t/0"},{"type":"function","title":"UXID.type/1","doc":"Returns the underlying schema type for a UXID.","ref":"UXID.html#type/1"},{"type":"type","title":"UXID.uxid_string/0","doc":"A UXID represented as a String","ref":"UXID.html#t:uxid_string/0"},{"type":"module","title":"UXID.Encoder","doc":"Encodes UXID structs into strings","ref":"UXID.Encoder.html"},{"type":"function","title":"UXID.Encoder.process/1","doc":"","ref":"UXID.Encoder.html#process/1"},{"type":"extras","title":"UXID","doc":"# UXID\n\n[![MIT License][badge_license_url]](LICENSE)\n[![Hex Version][badge_version_url]](https://hex.pm/packages/uxid)\n[![Hex Downloads][badge_downloads_url]](https://hex.pm/packages/uxid)\n\n**U**ser e**X**perience focused **ID**entifiers (UXIDs) are identifiers which:\n\n* Describe the resource (aid in debugging and investigation)\n* Work well with copy and paste (double clicking selects the entire ID)\n* Can be shortened for low cardinality resources\n* Are secure against enumeration attacks\n* Can be generated by application code (not tied to the datastore)\n* Are K-sortable (lexicographically sortable by time - works well with datastore indexing)\n* Do not require any coordination (human or automated) at startup, or generation\n* Are very unlikely to collide (more likely with less randomness)\n* Are easily and accurately transmitted to another human using a telephone\n\nMany of the concepts of Stripe IDs have been used in this library.","ref":"readme.html"},{"type":"extras","title":"Usage - UXID","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Generating UXIDs - UXID","doc":"```elixir\n# No options generates a basic ULID\nUXID.generate! # \"01emdgjf0dqxqj8fm78xe97y3h\"\n\n# A prefix can be provided\nUXID.generate! prefix: \"cus\" # \"cus_01emdgjf0dqxqj8fm78xe97y3h\"\n\n# The amount of randomness can be decreased for smaller cardinality resources\n# T-Shirt sizes can be used (xs, s, m, l, xl) or (xsmall, small, medium, large, xlarge)\nUXID.generate! prefix: \"cus\", size: :small # \"cus_01eqrh884aqyy1\"\n\n# Uppercase can be used to match previous UXID versions\nUXID.generate! case: :upper # \"01EMDGJF0DQXQJ8FM78XE97Y3H\"\n```","ref":"readme.html#generating-uxids"},{"type":"extras","title":"Ecto - UXID","doc":"UXIDs can be used as Ecto fields including primary keys.\n\n```elixir\ndefmodule YourApp.User do\n  use Ecto.Schema\n\n  @primary_key {:id, UXID, autogenerate: true, prefix: \"usr\", size: :medium}\n  schema \"users\" do\n    field :api_key, UXID, autogenerate: true, prefix: \"apikey\", size: :small\n    field :api_secret, UXID, autogenerate: true, prefix: \"apisecret\", size: :xlarge\n  end\nend\n```","ref":"readme.html#ecto"},{"type":"extras","title":"Installation - UXID","doc":"The package can be installed by adding `uxid` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:uxid, \"~> 2.0\"}\n  ]\nend\n```\n\nOnline documenttion can be found at [https://hexdocs.pm/uxid][hexdocs_project_url].\n\n\n<!-- LINKS -->\n[hex_project_url]: https://hex.pm/packages/uxid\n[hexdocs_project_url]: https://hexdocs.pm/uxid\n[mit_license_url]: http://opensource.org/licenses/MIT\n\n<!-- BADGES -->\n[badge_license_url]: https://img.shields.io/badge/license-MIT-brightgreen.svg?cacheSeconds=3600?style=flat-square\n[badge_downloads_url]: https://img.shields.io/hexpm/dt/uxid?style=flat&logo=elixir\n[badge_version_url]: https://img.shields.io/hexpm/v/uxid?style=flat&logo=elixir","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}